/* SPEEDUP Path Integral Monte Carlo code is developed by A. Balaz,
   D. Stojiljkovic, I. Vidanovic, A. Belic, and A. Bogojevic.
         
   Address: Institute of Physics, Belgrade, Serbia
   Scientific Computing Laboratory, http://www.scl.rs/

   Public use and modification of this code is allowed providing 
   the authors are properly acknowledged. The authors would be   
   grateful for all information and/or comments regarding the use   
   of the code.  
*/

/* USER CONFIGURABLE SECTION:


      This file supplies the C function for the evaluation of the potential
      V and its nonvanishing derivatives to order 2 p - 2 for the anharmonic
      potential V(x) = A * x^2 / 2 + g * x^2 / 24.

      Function V0(x) provides the value of the potential (variable V00),
      and all its nonvanishing derivatives to order 2 p - 2,
      variables V01, V02, ..., V34, at the point x. The default
      value for all these variables is zero, i.e. you need to
      define only nonzero derivatives.

      Parameters of the potential are par[0] ..., as entered on the
      command line. For the anharmonic oscillator: A = par[0], g = par[1].
*/

#include <1D-AHO.h>

void V0(double x)
{
   double x2, x4;

   x2 = x * x;
   x4 = x2 * x2;
   V00 = par[0] * x2 / 2 + par[1] * x4 / 24.;
   V01 = par[0] * x + par[1] * x2 * x / 6.;
   V02 = par[0] + par[1] * x2 / 2.;
   V03 = par[1] * x;
   V04 = par[1];

   return;
}
