/* NO USER CONFIGURABLE PARAMETERS HERE! */

/* SPEEDUP Path Integral Monte Carlo code is developed by A. Balaz,
   D. Stojiljkovic, I. Vidanovic, A. Belic, and A. Bogojevic.
         
   Address: Institute of Physics, Belgrade, Serbia
   Scientific Computing Laboratory, http://www.scl.rs/

   Public use and modification of this code is allowed providing 
   the authors are properly acknowledged. The authors would be   
   grateful for all information and/or comments regarding the use   
   of the code.  
*/

/* This is the header for the main.c file.*/

/* Necessary headers that should be included. */
#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include <sys/time.h>
#include <sprng_cpp.h>

/* Declarations of functions used in main.c. */
double func(double *, double, int, int); /* Calculates the function that is averaged. */
void distr(double *, int); /* Generates the paths. */
void mc(double, double *, double *, double *, int); /* Implements the Monte Carlo method. */

/* Variables needed for using the SPRNG random number generator. */
int streamnum, nstreams;
Sprng *stream;

/* Time of propagation, defined in main(). */
double T;

/* Parameters of the potential, defined in main(), used in V0(). */
double *par;

/* Array with powers of 2 (two[n] = 2^n), defined in main(), used in func(). */
int *two;

/* Array of path integral norms, defined in main(), used in func(). */
double *norm;

/* Array of the exponents of Gaussian probability distribution functions,
   defined in distr(), used in func(). */
double *distrexp;

/* Array of 2 sigma^2 and 1 / (2 sigma^2) values, where sigma^2 = eps = T / 2^n. */
double *dsigma2, *dsigma2inv;

/* dpi = 2 pi */
double dpi;
